
package de.frankmuenster.mahoe.banks.targobank.web.webpages;

import java.util.List;

import org.openqa.selenium.By;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebDriverException;
import org.openqa.selenium.WebElement;

import de.frankmuenster.mahoe.banks.targobank.TargoBank;
import de.frankmuenster.mahoe.banks.targobank.web.TargoBankWebAccountInformation;
import de.frankmuenster.mahoe.utils.Utils;
import de.frankmuenster.mahoe.utils.WebUtils;
import de.frankmuenster.mahoe.web.WebSiteException;
import de.frankmuenster.mahoe.web.WebSiteExceptionTypes;
import de.frankmuenster.mahoe.web.webpages.AbstractAccountPage;
import de.willuhn.logging.Logger;

public class TargoBankAccountPage extends AbstractAccountPage<TargoBankWebAccountInformation> {

    public TargoBankAccountPage(final WebDriver driver, final TargoBankWebAccountInformation accountInfo) {
        super(driver, accountInfo);

    }

    @Override
    public void open() throws WebSiteException {

        this.driver.get(TargoBank.URL_KTO_UEBERSICHT);

        if (!elementExist(By.id("I0:A1:al"))) {
            throw new WebDriverException("Kontenbersicht konnte nicht geffnet werden.");

        }
        WebElement link = null;

        final WebElement tableDiv = this.driver.findElement(By.id("I0:A1:al"));
        final List<WebElement> tables = tableDiv.findElements(By.tagName(WebUtils.HTML_TAG_TABLE));

        for (final WebElement table : tables) {
            final WebElement tableBody = table.findElement(By.tagName(WebUtils.HTML_TAG_TBODY));

            final List<WebElement> rows = tableBody.findElements(By.tagName(WebUtils.HTML_TAG_TR));

            for (final WebElement row : rows) {

                Logger.debug(row.toString());

                if (elementExist(By.tagName(WebUtils.HTML_TAG_TD))) {
                    final List<WebElement> cells = row.findElements(By.tagName(WebUtils.HTML_TAG_TD));
                    if (!cells.isEmpty() && isAccount(cells.get(0))) {
                        link = cells.get(0);
                        break;
                    }
                }
            }
        }

        // If link is null the account has not been found
        if (link == null) {
            throw new WebSiteException("KreditkartenKonto nicht gefunden", WebSiteExceptionTypes.ACCOUNT_NOT_FOUND);
        }
        // open account
        link.click();

        final WebElement check = this.driver.findElement(By.id("F12:T:ttlBlockRoot")); //$NON-NLS-1$

        Logger.debug(check.getText());
        if (!check.getText().contains("Kreditkartenbersicht")) { //$NON-NLS-1$
            throw new WebSiteException("Fehler beim ffnen der Kreditkartenbersicht",
                    WebSiteExceptionTypes.WEBSITE_NOT_REACHABLE);

        }

    }

    private boolean isAccount(final WebElement cell) {

        final String cellText = cell.getText().trim();
        Logger.debug("Zelle1: " + cellText); //$NON-NLS-1$

        final String linkName = this.accountInfo.getCardCompany() + "\n" //$NON-NLS-1$
                + Utils.maskCardNummer(this.accountInfo.getCardNumber()); // $NON-NLS-1$

        return cellText.endsWith(Utils.maskCardNummer(this.accountInfo.getCardNumber())) ? true : false;

    }

}
